@@ -7,6 +7,15 @@ class UnableToConnect(Exception):
         return f'{self.__class__.__name__}: Robotnik is unable to connect: {self.args}'
 
 
+class MalformedMessage(Exception):
+    def __init__(self, msg_input: str):
+        self.malformed_input = msg_input
+        super().__init__()
+
+    def __str__(self):
+        return f'Unable to decode RobotnikMQ message from: "{self.malformed_input}"'
+
+
 class FileDoesNotExist(Exception):
     msg = 'Cannot find'
 
